@@ -1,7 +1,7 @@
 package App::shcompgen;
 
 our $DATE = '2016-04-30'; # DATE
-our $VERSION = '0.16'; # VERSION
+our $VERSION = '0.17'; # VERSION
 
 use 5.010001;
 use strict;
@@ -188,8 +188,8 @@ complete -F _|."$prog $qprog".q|
     # - completer_command -> check completer command if it's pericmd or
     # glcomp or glsubc
 
-    $script = "# FRAGMENT id=shcompgen-header note=".$detres->[3]{'func.note'}.
-        "\n$script\n";
+    $script = "# FRAGMENT id=shcompgen-header note=".
+        ($detres->[3]{'func.note'} // ''). "\n$script\n";
 
     $script;
 }
@@ -689,7 +689,7 @@ App::shcompgen - Generate shell completion scripts
 
 =head1 VERSION
 
-This document describes version 0.16 of App::shcompgen (from Perl distribution App-shcompgen), released on 2016-04-30.
+This document describes version 0.17 of App::shcompgen (from Perl distribution App-shcompgen), released on 2016-04-30.
 
 =head1 FUNCTIONS
 
